﻿using UnityEngine;
using System.Collections;
using System.Collections.Generic;

public class PlayerControl : MonoBehaviour {

	private GameObject pauseScreen;
	public bool pause;

	//player rotation
	public Vector3 mousePos;
	public Vector3 objectPos;
	public float angle;
	public bool rotate;
	public Sprite[] directions;
	public bool faceMouse;

	//player motion
	public float moveMag = 5f;	//how fast the player moves
	public float dodgeMag = 15f;
	public float dodgeDuration = 0.5f;
	private Vector3 vel;

	//animator
	private Animator anim;
	private SpriteRenderer rend;
	private PlayerHealth ph;

	//private Crosshairs xHairs;	//the player's crosshairs
	private GameObject playerUI;

	//floats for directions
	public float dX;
	public float dZ;
	float xVel;
	float zVel;

	// Use this for initialization
	void Start () {
		faceMouse = false;

		anim = GetComponent<Animator>();
		anim.SetInteger("Direction", 0);

		ph = GetComponent<PlayerHealth>();

		playerUI = GameObject.FindGameObjectWithTag("PlayerUI");
		pauseScreen = GameObject.FindGameObjectWithTag("Pause");

		//xHairs = GameObject.FindGameObjectWithTag("Crosshairs").GetComponent<Crosshairs>();
		//playerUI = GameObject.FindGameObjectWithTag("PlayerUI");

		rend = GetComponent<SpriteRenderer>();

		pause = false;

		dX = 0f;
		dZ = 0f;
	}
	
	// Update is called once per frame
	void FixedUpdate () {
		vel = rigidbody.velocity;

		if (Input.GetKey(KeyCode.W)) {
			dZ = 1f;
		}
		else if (Input.GetKey(KeyCode.S)) {
			dZ = -1f;
		}
		else {
			dZ = 0f;
		}

		if (Input.GetKey(KeyCode.D)) {
			dX = 1.0f;
		}
		else if (Input.GetKey(KeyCode.A)) {
			dX = -1f;
		}
		
		else {
			dX = 0f;
		}

		//set the speed componenet for the animator so it can set us moving
		//anim.SetFloat("Speed", rigidbody.velocity.magnitude);


		//rotate the player to face the mouse
		mousePos = Camera.main.WorldToScreenPoint(Input.mousePosition);
		//get the player position form the camera
		objectPos = Camera.main.WorldToScreenPoint(transform.position);
		Vector3 dir = mousePos-objectPos;
		dir.Normalize();
		angle = Vector3.Angle(dir, transform.TransformDirection(Vector3.forward));

		if (faceMouse) {
			//transform.rotation = Quaternion.Euler(dir);
			Debug.Log("rotated");
		}

		if (/*ps.pause == false &&*/ pause == false) {
			//set velocity in two directions as range depending on what direction we're pushing the axis in

			//up
			if (dX == 0f && dZ == 1f ) {
				xVel = 1f;
				zVel = 1f;
				anim.SetInteger("Direction", 1);
			}
			//down
			else if (dX == 0f && dZ == -1.0f) {
				xVel = -1f;
				zVel = -1f;
				anim.SetInteger("Direction", 2);
			}
			//right
			else if (dX == 1f && dZ == 0) {
				xVel = 1f;
				zVel = -1f;
				anim.SetInteger("Direction", 3);
			}
			//left
			else if (dX == -1f && dZ == 0) {
				xVel = -1f;
				zVel = 1f;
				anim.SetInteger("Direction", 4);
			}
			//up-right
			else if (dX == 1f && dZ == 1f) {
				xVel = 1f;
				zVel = 0f;
				anim.SetInteger("Direction", 5);
			}
			//up-left
			else if (dX == -1f && dZ == 1f) {
				xVel = 0f;
				zVel = 1f;
				anim.SetInteger("Direction", 6);
			}
			//down-right
			else if (dX == 1f && dZ == -1f) {
				xVel = 0f;
				zVel = -1f;
				anim.SetInteger("Direction", 7);
			}
			//down-left
			else if (dX == -1f && dZ == -1f) {
				xVel = -1f;
				zVel = 0f;
				anim.SetInteger("Direction", 8);
			}
			//no direction
			else {
				xVel = 0f;
				zVel = 0f;
				anim.SetInteger("Direction", 0);
			}

			//Debug.Log("Direction: "+anim.GetInteger("Direction"));


			vel.x = xVel * moveMag;
			vel.z = zVel * moveMag;

			rigidbody.velocity = vel;

			//dodge
			if (Input.GetButtonDown("Jump")) {
				StartCoroutine(Dodge());
				//vel.y = 0;
				//transform.position += vel*dodgeMag;
			}

			//up
			if (dX == 0f && dZ == 1f) {
				rend.sprite = directions[0];
				rigidbody.rotation = Quaternion.Euler(new Vector3(0, 225, 0));
			}
			//moving up-left
			else if (dX <= -1 && dZ == 1) {
				rend.sprite = directions[1];
				rigidbody.rotation = Quaternion.Euler(new Vector3(0, 180, 0));
			}
			//left
			else if (dX == -1f && dZ == 0f) {
				rend.sprite = directions[2];
				rigidbody.rotation = Quaternion.Euler(new Vector3(0, 135, 0));
			}
			//moving down-left
			else if (dX == -1 && dZ <= -1) {
				rend.sprite = directions[3];
				rigidbody.rotation = Quaternion.Euler(new Vector3(0, 90, 0));
			}
			//right
			else if (dX == 1f && dZ == 0f) {
				rend.sprite = directions[6];
				rigidbody.rotation = Quaternion.Euler(new Vector3(0, 315, 0));
			}
			//moving up-right
			else if (dX == 1 && dZ == 1) {
				rend.sprite = directions[7];
				rigidbody.rotation = Quaternion.Euler(new Vector3(0, 270, 0));
			}
			//down
			else if (dX == 0f && dZ == -1f) {
				rend.sprite = directions[4];
				rigidbody.rotation = Quaternion.Euler(new Vector3(0, 45, 0));
			}
			//moving down-right
			else if (dX == 1 && dZ >= -1) {
				rend.sprite = directions[5];
				rigidbody.rotation = Quaternion.Euler(new Vector3(0, 360, 0));
			}
			//no condition for not moving as the sprite should stay the same
		}

		if (Input.GetKeyDown(KeyCode.Escape)) {
			pause = !pause;
			//Debug.Log("Pause"+pause);
		}

		if (!pause) {
			playerUI.SetActive(true);
			pauseScreen.SetActive(false);
		}
		else {
			playerUI.SetActive(false);
			pauseScreen.SetActive(true);
		}
	}

	//
	IEnumerator Dodge() {
		//moveMag = dodgeMag;
		ph.invincible = true;
		yield return new WaitForSeconds(dodgeDuration);
		vel.y = 0;
		transform.position += vel*dodgeMag;
		ph.invincible = false;
	}
}
